#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright 2011 Richard Dymond (rjdymond@gmail.com)
#
# This file is part of SkoolKit.
#
# SkoolKit is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# SkoolKit is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# SkoolKit. If not, see <http://www.gnu.org/licenses/>.

import sys
import os.path
from skoolkit.skoolsft import SftWriter

def parse_args(args):
    write_hex = False
    files = []
    i = 0
    while i < len(args):
        arg = args[i]
        if arg == '-h':
            write_hex = True
        elif len(arg) > 1 and arg[0] == '-':
            print_usage()
        else:
            files.append(arg)
        i += 1

    if len(files) != 1:
        print_usage()
    return files[0], write_hex

def print_usage():
    sys.stderr.write("""Usage: %s [options] FILE

  Convert a skool file into a skool file template, written to standard output.
  FILE may be a regular file, or '-' for standard input.

Options:
  -h  Write addresses in hexadecimal format
""" % os.path.basename(sys.argv[0]))
    sys.exit(1)

def run(skoolfile, write_hex):
    writer = SftWriter(skoolfile, write_hex)
    writer.write()

def main():
    run(*parse_args(sys.argv[1:]))

if __name__ == '__main__':
    main()
