; Source code for test-sna.bin (which is used by test_sna2skool.py).
;
; Designed to test the static code analysis algorithm used by sna2skool.py:
;
;   1. Insert block separators after byte sequences 201 ('RET'), 195,n,n
;      ('JP nn') and 24,d ('JR d').
;   2. Scan for adjacent blocks A and B that overlap (i.e. B starts in the
;      middle of the last instruction in A), and join them.
;   3. Scan the disassembly for blocks that don't end in a 'RET', 'JP nn' or
;      'JR d' instruction, and join them to the following block.
;   4. Scan the disassembly for pairs of adjacent blocks where the start
;      address of the second block is JRed or JPed to from the first block, and
;      join such pairs.
;   5. Mark any sequence of NOPs at the beginning of a block as a separate zero
;      block.

  ORG 16384

  RET

; Test the '-t' option.
  DEFM "162"
  RET

  ORG 32768

; Test that 'RET', 'JP nn' and 'JR d' create block boundaries.
LBL01A:
  LD A,B
  JP LBL01B
  XOR A
  RET
LBL01B:
  LD B,C
  JR LBL01A

; Test that byte sequences (201), (195,n,n) and (24,d) don't create block
; boundaries when they do not correspond to 'RET', 'JP nn' or 'JR d'
; instructions.
  LD A,201
  LD B,195
  LD C,128
  LD A,24
  RET

; Test that two adjacent blocks are joined when the first block JPs into the
; second block.
  AND A
  JP NZ,BLOCK2A
  INC A
  RET
BLOCK2A:
  DEC A
  RET

; Test that two adjacent blocks are joined when the first block JRs into the
; second block.
  AND A
  JR Z,BLOCK2B
  DEC A
  RET
BLOCK2B:
  INC A
  RET

; Test that a sequence of NOPs at the beginning of a block is marked as a
; separate zero block.
  DEFS 10
  AND A
  RET

; Make the object code 49152 bytes long (16384-65535) for convenience.
  ORG 65535

  NOP
